@@ -186,11 +186,8 @@ def _check_for_window_manager(screen):
 def _start_window_manager():
     global _metacity_process
 
-    settings = Gio.Settings.new('org.gnome.desktop.interface')
-    settings.set_string('cursor-theme', 'sugar')
-
     _metacity_process = subprocess.Popen(
-        ['metacity', '--no-force-fullscreen', '--no-composite'])
+        ['metacity', '--no-force-fullscreen'])
 
     screen = Wnck.Screen.get_default()
     screen.connect('window-manager-changed', __window_manager_changed_cb)
